summaryrefslogtreecommitdiff
path: root/include/user/power.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/user/power.h')
-rw-r--r--include/user/power.h4
1 files changed, 3 insertions, 1 deletions
diff --git a/include/user/power.h b/include/user/power.h
index 6e4df8c..592a499 100644
--- a/include/user/power.h
+++ b/include/user/power.h
@@ -25,7 +25,9 @@ int scePowerGetBatteryFullCapacity(); //?
int scePowerGetArmClockFrequency(); //Get Clock Frequency of the ARM
int scePowerGetBusClockFrequency(); //Get Clock Frequency of the BUS
int scePowerGetGpuClockFrequency(); //Get Clock Frequency of the Gpu
-int scePowerSetArmClockFrequency(int freq); // Set Cet Clock Frequency of the ARM
+int scePowerSetArmClockFrequency(int freq); // Set Clock Frequency of the ARM
+int scePowerSetBusClockFrequency(int freq); // Set Clock Frequency of the BUS
+int scePowerSetGpuClockFrequency(int freq); // Set Clock Frequency of the Gpu
#ifdef __cplusplus
}